var async = require('async');

module.exports = {
    '@tags': ['nl_search'],

    before: function (client) {
        client
            .url('http://localhost:3000')
            .waitForElementVisible('#topmenu', 1000);
    },

    after: function (client) {
        client.end();
    },

    /**
     * Test: 2-001
     * Expects:
     * - Nodes and node groups starting in "Local" will be listed alpahabetically
     * and will be followed by other nodes and node groups which contain "Local"
     * which are also sorted alphabetically
     */
    '2-001' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                node.clearValue('@inputSearch');
                node.setValue('@inputSearch', 'local', function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('@localizeMusic').to.be.visible;
                node.expect.element('@constantLocalization').to.be.visible;
                node.expect.element('@displayLocalization').to.be.visible;
                node.expect.element('@harkLocalization').to.be.visible;
                node.expect.element('@harkLocCor').to.be.visible;
                callback();
            }
        ], function(err, results) {
        });
    },

    /**
     * Test: 2-002
     * Expects:
     * Nodes and node groups starting in "a" will be listed alpahabetically
     * and will be followed by other nodes and node groups which contain "a"
     * which are also sorted alphabetically
     */
    '2-002' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                node.expect.element('@inputSearch').to.be.present;
                callback();
            },
            function (callback) {
                node.clearValue('@inputSearch');
                node.setValue('@inputSearch', 'a');
                callback();
            },
            function (callback) {
                node.expect.element('#flatNodelist').to.be.visible
                callback();
            },
            function (callback) {
                for (var i = 1; i <= 180; i++) {
                    node.expect.element('#flatNodelist > li:nth-child(' + i + ')').to.have.attribute('key').to.match(/[aA]/);
                }
                callback();
            }
        ], function(err, results) {
        });
    },

    /**
     * Test: 2-003
     * Expects:
     *  - A sheet named "a" will be added
     *  - Node search input is not changed.
     *  - Node list will display node groups which contain "a" (include Dynamic node "a")
     */
    '2-003' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                node.addSheet(function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('@addSheetInput').to.be.present;
                callback();
            },
            function (callback) {
                node.clearValue('@addSheetInput');
                node.setValue('@addSheetInput', 'a', function () {
                    callback();
                });
            },
            function (callback) {
                node.click('@addBtn', function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('@addSheetDialog').to.be.not.visible;
                node.expect.element('@sheetTab').to.be.present;
                node.expect.element('@nodeListA').to.be.present;
                client
                    .moveToElement('#nodelistSearch > input[type="text"]', 10,2)
                    .mouseButtonClick('left', function () {
                        callback();
                    });
            },
            function (callback) {
                client.keys([client.Keys.CONTROL,'a'], function () {
                    callback();
                });
            },
            function (callback) {
                client.keys(client.Keys.BACK_SPACE, function () {
                    callback();
                });
            },
            function (callback) {
                node.api.pause(1000, function () {
                    node.expect.element('@dynamicNode').to.be.visible;
                    callback();
                });
            },
            function (callback) {
                node.clickDynamic(function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('@dynamicA').to.be.visible;
                callback();
            }
        ], function(err, results) {
        });
    },

    /**
     * Test: 2-004
     * Expects:
     *  - Node menu will be displayed
     *  - Menu will contain the node "a"
     */
    '2-004' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                node.expect.element('@inputSearch').to.be.present;
                callback();
            },
            function (callback) {
                client
                    .moveToElement('#nodelistSearch > input[type="text"]', 10,2)
                    .mouseButtonClick('left', function () {
                        callback();
                    });
            },
            function (callback) {
                client.keys([client.Keys.CONTROL,'a'], function () {
                    callback();
                });
            },
            function (callback) {
                client.keys(client.Keys.BACK_SPACE, function () {
                    callback();
                });
            },
            function (callback) {
                client.keys('a', function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('#flatNodelist').to.be.visible;
                callback();
            },
        ], function(err, results) {
        });
    },

    /**
     * Test: 2-005
     * Expects:
     *  - A sheet named "b" will be added
     *  - Node search input should not be cleared
     *  - Node list will display all available node groups that contains 'a'
     */
    '2-005' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                node.addSheet(function () {
                    callback();
                });
            },
            function (callback) {
                node.expect.element('@addSheetInput').to.be.present;
                callback();
            },
            function (callback) {
                node.clearValue('@addSheetInput');
                node.setValue('@addSheetInput', 'b', function () {
                    callback();
                });
            },
            function (callback) {
                node.click('@addBtn', function () {
                    node.api.pause(1000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                node.expect.element('@addSheetDialog').to.be.not.visible;
                node.expect.element('@sheetTab').to.be.present;
                node.expect.element('@nodeListA').to.be.present;
                node.expect.element('@nodeListB').to.be.not.visible;
                callback();
            }
        ], function(err, results) {
        });
    },

    /**
     * Test: 2-006
     * Expects:
     *  - Node menu will be displayed
     *  - Menu will contain the node "a" and "b"
     */
    '2-006' : function (client) {

        var node = client.page.node();

        async.series([
            function (callback) {
                node.click('@nodeDynamic');
                callback();
            },
            function (callback) {
                node.expect.element('@nodeListA').to.be.present;
                node.expect.element('@nodeListB').to.be.present;
                callback();
            },

        ], function(err, results) {
        });
    },
};